#
# spec file for package v2ray-core
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define   provider        github
%define   provider_tld    com
%define   project         v2fly
%define   repo            v2ray-core
# https://github.com/v2fly/v2ray-core
%define   provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%define   import_path     github.com/v2fly/v2ray-core/v4

Name:           v2ray-core
Version:        4.35.1
Release:        bp153.1.21
Summary:        Network tools for building a computer network
License:        MIT
Group:          Productivity/Networking/Web/Proxy
URL:            https://github.com/v2fly/v2ray-core
Source0:        https://github.com/v2fly/v2ray-core/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        v2ray.service
Source3:        v2ray@.service
Source99:       %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
# This package can not be built with go version < 1.15
BuildRequires:  golang(API) = 1.15
BuildRequires:  pkgconfig(systemd)
AutoReqProv:    Off
Provides:       v2ray = %{version}-%{release}
Obsoletes:      v2ray < %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{go_provides}
%{?systemd_ordering}

%description
Project V is a set of network tools for building a computer network.
It secures network connections and protects privacy.

%package -n golang-%{provider}-%{project}-%{repo}
Summary:        Additional mobile libraries
Group:          Development/Languages/Golang
BuildArch:      noarch

%description -n golang-%{provider}-%{project}-%{repo}
Project V is a set of network tools for building a computer network.
It secures network connections and protects privacy.

This package provide source code for %{repo}

%prep
%setup -q -a1 -n %{repo}-%{version}
rm go.sum go.mod

%build
%goprep %{import_path}
%gobuild main...
mv %{_builddir}/go/bin/main %{_builddir}/go/bin/v2ray
%gobuild infra/control/main...
mv %{_builddir}/go/bin/main %{_builddir}/go/bin/v2ctl

%install
%goinstall
%gosrc
%gofilelist

install -d %{buildroot}%{_datadir}/v2ray
install -m0644 release/config/geoip.dat %{buildroot}%{_datadir}/v2ray/
install -m0644 release/config/geosite.dat %{buildroot}%{_datadir}/v2ray/

install -d %{buildroot}%{_unitdir}
install -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/
install -m0644 %{SOURCE3} %{buildroot}%{_unitdir}/

install -d %{buildroot}%{_sysconfdir}/v2ray
install -m0644 release/config/*.json %{buildroot}%{_sysconfdir}/v2ray/

install -d %{buildroot}%{_sbindir}/
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcv2ray

%fdupes %{buildroot}

%pre
%service_add_pre v2ray.service v2ray@.service

%post
%service_add_post v2ray.service v2ray@.service

%preun
%service_del_preun v2ray.service v2ray@.service

%postun
%service_del_postun v2ray.service v2ray@.service

%files
%doc README.md
%license LICENSE
%{_bindir}/v2ray
%{_bindir}/v2ctl
%{_unitdir}/v2ray.service
%{_unitdir}/v2ray@.service
%dir %{_sysconfdir}/v2ray
%dir %{_datadir}/v2ray
%{_datadir}/v2ray/*
%config(noreplace) %{_sysconfdir}/v2ray/*.json
%{_sbindir}/rcv2ray

%files -n golang-%{provider}-%{project}-%{repo} -f file.lst
%doc README.md
%license LICENSE

%changelog
* Tue Mar  9 2021 opensuse-packaging <opensuse-packaging@opensuse.org>
- update version to 4.35.1
  * Add support for FakeDNS (#395 #406 #696) @yuhan6665
  * Add streamSetting / transport support for outbound front proxy
  * Add zero pseudo encryption for better performance VMess
  * Add support to disable compatibility for legacy VMess MD5 (#596) @dyhkwong
  * Add a faster and more memory-efficient routing rule matcher
    HybridDomainMatcher (#587 #639) @darsvador
  * Add support to disable DNS cache (#699 #705) @CalmLong
  * Fix test HTTP/2 dial timeout (#570) @kslr
  * Fix Trojan panic when UDP dispatcher fails to write response (#599) @maskedeken
  * Fix TCP default ALPN (#716) @AkinoKaede
  * Fix DNS rule index out of range (#727) @Loyalsoldier
  Check https://github.com/v2fly/v2ray-core/releases/tag/v4.35.1 for more info
- update import path to github.com/v2fly/v2ray-core/v4
* Sat Jan  9 2021 opensuse-packaging <opensuse-packaging@opensuse.org>
- update version to 4.34.0
  * Disable TLS Session Resumption by default
  * Remove legacy Shadowsocks unsecure stream ciphers
  * Add preliminary support for DNS over QUIC
* Tue Dec 29 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Rename golang-github-v2ray-v2ray-core to golang-github-v2fly-v2ray-core
- Update vendor.
* Wed Nov 25 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- update to version 4.33.0
  * Remove XTLS
  * API: Reflection Service Support @Vigilans
  * Update to IETF QUIC draft-32
- update in 4.32.1
  * VLESS XTLS Direct Mode ReadV Experiment
  * Disable 0-RTT mechanism for HTTP/1.x outbound
  * Set default alterId to 0 for VMess dynamic ports
* Sun Nov  1 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- update version to 4.32.0
  * loads JSON internally by default @forever8938
  * Refine UNIX domain socket @lucifer9
  * Fix mKCP sending window @p4gefau1t
  * Fix JSON parsing dependency introduced by mutijson config @xiaokangwang
  * Fix proto.go ProtoFilesUsingProtocGenGoFast on Windows @JimhHan
- other changes before this version
  * Add full VLESS fallbacks support to Trojan
  * Add Trojan over XTLS support @maskedeken
  * Add XTLS Direct Mode
  * Add XTLS support to mKCP
  * Add padding to abstract UNIX domain socket in fallbacks
  * Add XTLS support to DomainSocket @rprx
* Mon Sep 28 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.29.0
  * Fix issue#202
  * Fix issue#203
  * Routing: Implement Route interface as the routing result of Router
  * kcp: removing annoying NewAEADAESGCMBasedOnSeed hint
  * Make isAEAD more efficient
  * Golangci-lint: disable some plugins
  * Add XTLS support
  * CodeQL: do NOT run on ready for review status
* Sat Sep 12 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.28.1
  * Fix incorrect IV usage which slightly reduced security
* Fri Sep 11 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.28.0
  * Changes
  - VMess AEAD will be used when alterId is 0. ("testsEnabled" is discarded)
  * Fixes
  - Fix dns tests by setting v2ray.location.asset @felixonmars
  - fix abstract UDS & add PROXY protocol support to DS inbound @lucifer9 @rprx
  - Systemd: prevent restart on corrupt config @DuckSoft
  * Chores
  - Upgrade all dependencies @rprx
  - Change lint order to avoid file changes notice @Loyalsoldier
  - Update geoip, geosite
* Wed Sep  2 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.27.5
  * Features
  - Parse X-Forwarded-For in http transport @lucifer9
  * Fix
  - Fix according to staticcheck result @Loyalsoldier
  - Fix: Bound check when accessing DNS server's ipIndexMap @Vigilans
  - Refine code @Loyalsoldier
  * Warning
  - In version v4.28.0 and later, VMess AEAD will be enabled when alterId is
    set to 0
* Sat Aug 29 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.27.4
  * Features
  - Dotless domain support in built-in DNS @Vigilans
  - Support source port matching in routing config @Vigilans
  - Make HTTP outbound 0-rtt @darhwa
  - Add asset location auto search @vcptr
  - Add PROXY protocol support to TCP & WebSocket inbound @lucifer9 and @rprx
  - VLESS PREVIEW 1.5 @rprx
  * Fixs
  - Amending domain matcher with returning array of all matches @Vigilans
  - Refactor DNS Server to record original rule of domain matchers @Vigilans
  - New Systemd unit file @dctxmei
  - Fix: logging empty rules & DNS @Loyalsoldier
  - Fix a typo @dikaixu1999
  - Shadowsocks Detection defense @studentmain and @xiaokangwang
  - Update Old file @Loyalsoldier
  * Breaking Changes
  - VLESS fallback -> fallbacks,
    see https://www.v2fly.org/config/protocols/vless.html
  - Route matching order changes
  * Warning
  - In version v4.28.0 and later, VMess AEAD will be enabled when alterId is
    set to 0
- Update in 4.27.0
  * Feature
  - VLESS PREVIEW 1.3 https://www.v2fly.org/config/protocols/vless.html
  * Fix
  - Shadowsocks supports cipher as None @yuhan6665
  - Add access log for Dokodemo inbound @lucifer9
  - Some typo fixes @DuckSoft
  - Add Linux riscv64 release @rprx
  - Fix the error of missing curl in Dockerfile @kallydev
  - GitHub Actions push to docker hub @kallydev
  - Optimize SO_REUSEPORT implementation @Vigilans
  - DOH supports HTTP/2 @darhwa
  - Apply Sockopt from inbound config to Dokodemo Tproxy's response connection
  @Vigilans
  * Breaking Change
  - VMessAEAD has been updated and needs both client and server to be the same
    version for it to work.
  - Release file structure changes.
  * Warning
  - In version v4.28.0 and later, VMess AEAD will be enabled when alterId is
    set to 0
* Sun Aug  2 2020 Sam Yu <ytz1995@hotmail.com>
- Fix out-of-box usability
* Fri Jul 10 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version to 4.26.0
  * Update Signing key
  * Update geoip, geosite
  * Fix bug with tag name extract
  * Generate Manifest for bleeding edge release
  * Adjust arm build
  * Allow the use of Browser Bridge
* Thu Jun 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update summary with something useful. Trim filler wording
  from description.
* Sun Jun 21 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- Update version  to 4.25.0
  * VMess's new header format experiment begins. You can now enable VMessAEAD to
    be better protected. Documents EN CH are updated. See extra-VMessAEADdoc.zip
    for a more detailed explanation available in both Chinese and English.
  * mKCP can now be encrypted to resist recognition, address issue mentioned in
    [#2530] #2253 #2131. Documents EN CH are updated.
  * Updated Golang tool-chain. Thanks @rprx
  * LocalAddr() in UDP workers will now return correct local addr. Thanks
    @zhuobixin
  * Further remove the identity leakage with TLS ClientHello from #2521 thank
    @darhwa
  * Fix UDP stability issue in Socks5 inbound, Shadowsocks inbound, and
    Dokodemo( TProxy ) inbound. This should alleviate unnecessary CPU, memory
    usage, and premature disconnection issue typically triggered by playing
    games, video conference, and Torrenting. See #2565 thank @JimHan75d8c5
    @xiaokangwang and Other testers @1265578519 @zhj9709 @Kylejustknows etc
  * Added ARM v5 binary in the release. This should allow legacy ARM devices to
    run V2Ray correctly. See #2536
* Sun Jun  7 2020 opensuse-packaging <opensuse-packaging@opensuse.org>
- initial package for version 4.23.4
